==> arc_eval-0.2.4.tar.gz: arc_eval-0.2.4/setup.py <==
#!/usr/bin/env python3
"""
AgentEval CLI setup configuration.
"""

from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="agent-eval",
    version="0.2.4",
    author="AgentEval Team",
    description="Domain-specific evaluation and compliance reporting for LLMs and AI agents",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.9",
    install_requires=[
        "click>=8.0.0",
        "pyyaml>=6.0",
        "rich>=13.0.0",
        "reportlab>=4.0.0",
        "tabulate>=0.9.0",
    ],
    extras_require={
        "dev": [
            "pytest>=7.0.0",
            "pytest-cov>=4.0.0",
            "black>=23.0.0",
            "flake8>=6.0.0",
            "mypy>=1.0.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "agent-eval=agent_eval.cli:main",
        ],
    },
    include_package_data=True,
    package_data={
        "agent_eval": ["domains/*.yaml"],
    },
)

==> arc_eval-0.2.6.tar.gz: arc_eval-0.2.6/setup.py <==
#!/usr/bin/env python3
"""
AgentEval CLI setup configuration.
"""

from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="arc-eval",
    version="0.2.6",
    author="ARC-Eval Team",
    description="Agentic Workflow Reliability Platform - Debug, Comply, Improve",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.9",
    install_requires=[
        "click>=8.0.0",
        "pyyaml>=6.0",
        "rich>=13.0.0",
        "reportlab>=4.0.0",
        "tabulate>=0.9.0",
    ],
    extras_require={
        "dev": [
            "pytest>=7.0.0",
            "pytest-cov>=4.0.0",
            "black>=23.0.0",
            "flake8>=6.0.0",
            "mypy>=1.0.0",
        ],
    },
    entry_points={
        "console_scripts": [
            "arc-eval=agent_eval.cli:main",
            "agent-eval=agent_eval.cli:main",  # Legacy alias for backward compatibility
        ],
    },
    include_package_data=True,
    package_data={
        "agent_eval": ["domains/*.yaml"],
    },
)
